@@ -1,6 +1,4 @@
-/* © 2006-2007 Anselm R. Garbe <garbeam at gmail dot com>
- * © 2006-2007 Sander van Dijk <a dot h dot vandijk at gmail dot com>
- * See LICENSE file for license details. */
+/* See LICENSE file for copyright and license details. */
 #include "dwm.h"
 #include <stdio.h>
 #include <stdlib.h>
@@ -218,11 +216,10 @@ configurenotify(XEvent *e) {
 	if (ev->window == root && (ev->width != sw || ev->height != sh)) {
 		sw = ev->width;
 		sh = ev->height;
-		wah = sh - bh;
-		waw = sw;
 		XFreePixmap(dpy, dc.drawable);
 		dc.drawable = XCreatePixmap(dpy, root, sw, bh, DefaultDepth(dpy, screen));
 		XResizeWindow(dpy, barwin, sw, bh);
+		updatebarpos();
 		lt->arrange();
 	}
 }
@@ -243,11 +240,11 @@ enternotify(XEvent *e) {
 
 	if(ev->mode != NotifyNormal || ev->detail == NotifyInferior)
 		return;
-	if((c = getclient(ev->window)) && isvisible(c))
+	if((c = getclient(ev->window)))
 		focus(c);
 	else if(ev->window == root) {
 		selscreen = True;
-		focustopvisible();
+		focus(NULL);
 	}
 }
 
